package com.game.business.service;

import java.util.List;
import com.game.business.domain.ShopSubOrder;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 订单商品Service接口
 *
 * @author game
 * @date 2024-09-06
 */
public interface IShopSubOrderService extends IService<ShopSubOrder> {
    /**
     * 查询订单商品
     *
     * @param id 订单商品主键
     * @return 订单商品
     */
    public ShopSubOrder selectShopSubOrderById(Long id);

    /**
     * 查询订单商品列表
     *
     * @param shopSubOrder 订单商品
     * @return 订单商品集合
     */
    public List<ShopSubOrder> selectShopSubOrderList(ShopSubOrder shopSubOrder);

    /**
     * 新增订单商品
     *
     * @param shopSubOrder 订单商品
     * @return 结果
     */
    public int insertShopSubOrder(ShopSubOrder shopSubOrder);

    /**
     * 修改订单商品
     *
     * @param shopSubOrder 订单商品
     * @return 结果
     */
    public int updateShopSubOrder(ShopSubOrder shopSubOrder);

    /**
     * 批量删除订单商品
     *
     * @param ids 需要删除的订单商品主键集合
     * @return 结果
     */
    public int deleteShopSubOrderByIds(Long[] ids);

    /**
     * 删除订单商品信息
     *
     * @param id 订单商品主键
     * @return 结果
     */
    public int deleteShopSubOrderById(Long id);
}